@@ -205,8 +205,8 @@ bool USRPDevice::start()
   writeLock.unlock();
 
   // Set gains to midpoint
-  setTxGain((minTxGain() + maxTxGain()) / 2);
-  setRxGain((minRxGain() + maxRxGain()) / 2);
+  setTxGain((m_dbTx->gain_min() + m_dbTx->gain_max()) / 2);
+  setRxGain((m_dbTx->gain_min() + m_dbTx->gain_max()) / 2);
 
   data = new short[currDataSize];
   dataStart = 0;
@@ -243,16 +243,6 @@ bool USRPDevice::stop()
 #endif
 }
 
-double USRPDevice::maxTxGain()
-{
-  return m_dbTx->gain_max();
-}
-
-double USRPDevice::minTxGain()
-{
-  return m_dbTx->gain_min();
-}
-
 double USRPDevice::maxRxGain()
 {
   return m_dbRx->gain_max();
@@ -271,10 +261,10 @@ double USRPDevice::setTxGain(double dB, size_t chan)
   }
 
   writeLock.lock();
-  if (dB > maxTxGain())
-    dB = maxTxGain();
-  if (dB < minTxGain())
-    dB = minTxGain();
+  if (dB > m_dbTx->gain_max())
+    dB = m_dbTx->gain_max();
+  if (dB < m_dbTx->gain_min())
+    dB = m_dbTx->gain_min();
 
   LOGC(DDEV, NOTICE) << "Setting TX gain to " << dB << " dB.";
 
@@ -314,6 +304,23 @@ double USRPDevice::setRxGain(double dB, size_t chan)
   return rxGain;
 }
 
+double USRPDevice::setPowerAttenuation(int atten, size_t chan) {
+      double rfGain;
+      rfGain = setTxGain(m_dbTx->gain_max() - atten, chan);
+      return m_dbTx->gain_max() - rfGain;
+}
+double USRPDevice::getPowerAttenuation(size_t chan) {
+      return m_dbTx->gain_max() - getTxGain(chan);
+}
+
+int USRPDevice::getNominalTxPower(size_t chan)
+{
+	/* TODO: return value based on some experimentally generated table depending on
+	 * band/arfcn, which is known here thanks to TXTUNE
+	 */
+	return 23;
+}
+
 bool USRPDevice::setRxAntenna(const std::string &ant, size_t chan)
 {
 	if (chan >= rx_paths.size()) {
@@ -365,7 +372,7 @@ GSM::Time USRPDevice::minLatency() {
 
 // NOTE: Assumes sequential reads
 int USRPDevice::readSamples(std::vector<short *> &bufs, int len, bool *overrun,
-                            TIMESTAMP timestamp, bool *underrun, unsigned *RSSI)
+                            TIMESTAMP timestamp, bool *underrun)
 {
 #ifndef SWLOOPBACK
   if (!m_uRx)
@@ -433,8 +440,10 @@ int USRPDevice::readSamples(std::vector<short *> &bufs, int len, bool *overrun,
 	*underrun = true;
 	LOGC(DDEV, DEBUG) << "UNDERRUN in TRX->USRP interface";
       }
-      if (RSSI) *RSSI = (word0 >> 21) & 0x3f;
-
+#if 0
+      /* FIXME: Do something with this ? */
+      unsigned RSSI = (word0 >> 21) & 0x3f;
+#endif
       if (!isAligned) continue;
 
       unsigned cursorStart = pktTimestamp - timeStart + dataStart;
@@ -513,9 +522,8 @@ int USRPDevice::readSamples(std::vector<short *> &bufs, int len, bool *overrun,
 #endif
 }
 
-int USRPDevice::writeSamples(std::vector<short *> &bufs, int len,
-                             bool *underrun, unsigned long long timestamp,
-                             bool isControl)
+int USRPDevice::writeSamplesControl(std::vector<short *> &bufs, int len,
+                             bool *underrun, unsigned long long timestamp, bool isControl)
 {
   writeLock.lock();
 
@@ -569,6 +577,12 @@ int USRPDevice::writeSamples(std::vector<short *> &bufs, int len,
 #endif
 }
 
+int USRPDevice::writeSamples(std::vector<short *> &bufs, int len,
+                             bool *underrun, unsigned long long timestamp)
+{
+  return writeSamplesControl(bufs, len, underrun, timestamp, false);
+}
+
 bool USRPDevice::updateAlignment(TIMESTAMP timestamp)
 {
 #ifndef SWLOOPBACK
@@ -578,7 +592,7 @@ bool USRPDevice::updateAlignment(TIMESTAMP timestamp)
   bool tmpUnderrun;
 
   std::vector<short *> buf(1, data);
-  if (writeSamples(buf, 1, &tmpUnderrun, timestamp & 0x0ffffffffll, true)) {
+  if (writeSamplesControl(buf, 1, &tmpUnderrun, timestamp & 0x0ffffffffll, true)) {
     pingTimestamp = timestamp;
     return true;
   }
